@@ -23,6 +23,9 @@ FAILEDOPERATION = 'FailedOperation'
 # 内核响应超时。
 FAILEDOPERATION_KERNELRESPONSETIMEOUT = 'FailedOperation.KernelResponseTimeout'
 
+# 当前实例已开启外网访问。
+FAILEDOPERATION_NOTALLOWMODIFYADDRAFTEROPENWANSERVICE = 'FailedOperation.NotAllowModifyAddrAfterOpenWanService'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -44,7 +47,7 @@ INVALIDPARAMETER_CURRENTINSTANCENOTSUPPORTMODIFYPARAMS = 'InvalidParameter.Curre
 # 无效Vip信息。
 INVALIDPARAMETER_INVALIDVIP = 'InvalidParameter.InvalidVip'
 
-# 当前子帐号无权执行该操作。
+# 当前子账号无权执行该操作。
 INVALIDPARAMETER_PERMISSIONDENIED = 'InvalidParameter.PermissionDenied'
 
 # 可用区已关闭售卖。
